@@ -56,7 +56,7 @@ class CallTracer(vm.VirtualMachine):
   _CONSTRUCTORS = ("__new__", "__init__")
 
   def __init__(self, *args, **kwargs):
-    super(CallTracer, self).__init__(*args, **kwargs)
+    super().__init__(*args, **kwargs)
     self._unknowns = {}
     self._builtin_map = {}
     self._calls = set()
@@ -742,5 +742,5 @@ def _maybe_output_debug(options, program):
     if options.output_debug == "-":
       log.info("=========== Program Dump =============\n%s", text)
     else:
-      with open(options.output_debug, "w") as fi:
+      with options.open_function(options.output_debug, "w") as fi:
         fi.write(text)
