@@ -1,4 +1,3 @@
-# Lint as: python3
 """Code and data structures for storing and displaying errors."""
 
 import collections
@@ -158,7 +157,7 @@ def _function_name(name, capitalize=False):
     return ret
 
 
-class CheckPoint(object):
+class CheckPoint:
   """Represents a position in an error log."""
 
   def __init__(self, errors):
@@ -171,7 +170,7 @@ class CheckPoint(object):
     self._errorlog_errors[:] = self._errorlog_errors[:self._position]
 
 
-class Error(object):
+class Error:
   """Representation of an error in the error log.
 
   Attributes:
@@ -325,7 +324,7 @@ class Error(object):
           traceback=None)
 
 
-class ErrorLogBase(object):
+class ErrorLogBase:
   """A stream of errors."""
 
   def __init__(self):
@@ -395,13 +394,13 @@ class ErrorLogBase(object):
     _log.info("Restored errorlog to checkpoint: %d errors reverted",
               len(checkpoint.errors))
 
-  def print_to_csv_file(self, filename):
+  def print_to_csv_file(self, filename, open_function=open):
     """Print the errorlog to a csv file."""
-    with open(filename, "w") as f:
+    with open_function(filename, "w") as f:
       csv_file = csv.writer(f, delimiter=",")
       for error in self.unique_sorted_errors():
         # pylint: disable=protected-access
-        # TODO(kramm): Add _methodname
+        # TODO(b/159038861): Add _methodname
         if error._details and error._traceback:
           details = error._details + "\n\n" + error._traceback
         elif error._traceback:
@@ -510,6 +509,14 @@ class ErrorLog(ErrorLogBase):
     with t.vm.convert.pytd_convert.produce_detailed_output():
       return self._pytd_print(t.to_type())
 
+  def _print_as_generic_type(self, t):
+    generic = pytd_utils.MakeClassOrContainerType(
+        t.get_instance_type().base_type,
+        t.formal_type_parameters.keys(),
+        False)
+    with t.vm.convert.pytd_convert.produce_detailed_output():
+      return self._pytd_print(generic)
+
   def _print_as_return_type(self, t):
     ret = self._pytd_print(t)
     # typing.NoReturn is a prettier alias for nothing.
@@ -1023,6 +1030,38 @@ class ErrorLog(ErrorLogBase):
     err_msg = "Type annotation%s does not match type of assignment" % suffix
     self.error(stack, err_msg, details=details)
 
+  @_error_name("container-type-mismatch")
+  def container_type_mismatch(self, stack, obj, mutations, name):
+    """Invalid combination of annotation and mutation.
+
+    Args:
+      stack: the frame stack
+      obj: the container instance being mutated
+      mutations: a dict of {parameter name: (annotated types, new types)}
+      name: the variable name (or None)
+    """
+    cls = obj.cls
+    annot_string = "%s (type parameters %s)" % (
+        self._print_as_expected_type(cls),
+        self._print_as_generic_type(cls))
+    details = "Annotation: %s\n" % annot_string
+    contained = ""
+    new_contained = ""
+    for formal in cls.formal_type_parameters.keys():
+      if formal in mutations:
+        params, values, _ = mutations[formal]
+        old_content = self._join_printed_types(
+            set(self._print_as_actual_type(v) for v in params.data))
+        new_content = self._join_printed_types(
+            set(self._print_as_actual_type(v) for v in values.data))
+        contained += "  %s: %s\n" % (formal, old_content)
+        new_contained += "  %s: %s\n" % (formal, new_content)
+    details += ("Contained types:\n" + contained +
+                "New contained types:\n" + new_contained)
+    suffix = "" if name is None else " for " + name
+    err_msg = "New container type%s does not match type annotation" % suffix
+    self.error(stack, err_msg, details=details)
+
   @_error_name("invalid-function-definition")
   def invalid_function_definition(self, stack, msg):
     """Invalid function constructed via metaprogramming."""
